abacusai.annotation_config — AbacusAI documentation

# abacusai.annotation_config

## Classes

`AnnotationConfig` | Annotation config for a feature group

## Module Contents

class abacusai.annotation_config.AnnotationConfig(client, featureAnnotationConfigs=None, labels=None, statusFeature=None, commentsFeatures=None, metadataFeature=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Annotation config for a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureAnnotationConfigs (list) – List of feature annotation configs

    - labels (list) – List of labels

    - statusFeature (str) – Name of the feature that contains the status of the annotation (Optional)

    - commentsFeatures (list) – Features that contain comments for the annotation (Optional)

    - metadataFeature (str) – Name of the feature that contains the metadata for the annotation (Optional)

  feature_annotation_configs
  labels
  status_feature
  comments_features
  metadata_feature
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict